from .backends import BackendTest
from .commands import CommandTest
from .mail import MailTest
from .models import ModelTest
from .utils import UtilsTest
from .cache import CacheTest
from .views import AdminViewTest
